@@ -21,8 +21,9 @@
 
 #include <powerdevil_debug.h>
 
-#include <QtCore/QDir>
-#include <QtCore/QDebug>
+#include <QDir>
+#include <QDebug>
+
 #include <KLocalizedString>
 
 #include <sys/utsname.h>
@@ -40,20 +41,14 @@
 
 #define PREFIX "/sys/class/backlight/"
 
-BacklightHelper::BacklightHelper(QObject * parent)
-    : QObject(parent), m_isSupported(false)
+BacklightHelper::BacklightHelper(QObject *parent) : QObject(parent)
 {
     init();
 }
 
 void BacklightHelper::init()
 {
-
-    if (useWhitelistInit()) {
-        initUsingWhitelist();
-    } else {
-        initUsingBacklightType();
-    }
+    initUsingBacklightType();
 
     if (m_dirname.isEmpty()) {
         initUsingSysctl();
@@ -119,67 +114,6 @@ void BacklightHelper::initUsingBacklightType()
     }
 }
 
-
-void BacklightHelper::initUsingWhitelist()
-{
-    QStringList interfaces;
-    interfaces << "nv_backlight" << "radeon_bl" << "mbp_backlight" << "asus_laptop"
-               << "toshiba" << "eeepc" << "thinkpad_screen" << "acpi_video1" << "acpi_video0"
-               << "intel_backlight" << "apple_backlight" << "fujitsu-laptop" << "samsung"
-               << "nvidia_backlight" << "dell_backlight" << "sony" << "pwm-backlight"
-               ;
-
-    QDir dir;
-    foreach (const QString & interface, interfaces) {
-        dir.setPath(PREFIX + interface);
-        //qCDebug(POWERDEVIL) << "searching dir:" << dir;
-        if (dir.exists()) {
-            m_dirname = dir.path();
-            //qCDebug(POWERDEVIL) << "kernel backlight support found in" << m_dirname;
-            break;
-        }
-    }
-
-    //If none of our whitelisted interface is available, get the first one  (if any)
-    if (m_dirname.isEmpty()) {
-        dir.setPath(PREFIX);
-        dir.setFilter(QDir::AllDirs | QDir::NoDot | QDir::NoDotDot | QDir::NoDotAndDotDot | QDir::Readable);
-        QStringList dirList = dir.entryList();
-        if (!dirList.isEmpty()) {
-            m_dirname = dirList.first();
-        }
-    }
-}
-
-bool BacklightHelper::useWhitelistInit()
-{
-    struct utsname uts;
-    uname(&uts);
-
-    int major, minor, patch, result;
-    result = sscanf(uts.release, "%d.%d", &major, &minor);
-
-    if (result != 2) {
-        return true; // Malformed version
-    }
-
-    if (major >= 3) {
-        return false; //Kernel 3+, we want type based init
-    }
-
-    result = sscanf(uts.release, "%d.%d.%d", &major, &minor, &patch);
-
-    if (result != 3) {
-        return true; // Malformed version
-    }
-
-    if (patch < 37) {
-        return true; //Minor than 2.6.37, use whiteList based
-    }
-
-    return false;//Use Type based interafce
-}
-
 void BacklightHelper::initUsingSysctl()
 {
 #ifdef USE_SYSCTL
@@ -234,7 +168,7 @@ void BacklightHelper::initUsingSysctl()
 #endif
 }
 
-ActionReply BacklightHelper::brightnessvalue(const QVariantMap & args)
+ActionReply BacklightHelper::brightness(const QVariantMap &args)
 {
     Q_UNUSED(args);
 
@@ -269,17 +203,17 @@ ActionReply BacklightHelper::brightnessvalue(const QVariantMap & args)
 #endif
 
     //qCDebug(POWERDEVIL) << "brightness:" << brightness;
-    reply.addData("brightnessvalue", brightness);
-    //qCDebug(POWERDEVIL) << "data contains:" << reply.data()["brightnessvalue"];
+    reply.addData("brightness", brightness);
+    //qCDebug(POWERDEVIL) << "data contains:" << reply.data()["brightness"];
 
     return reply;
 }
 
-ActionReply BacklightHelper::setbrightnessvalue(const QVariantMap & args)
+ActionReply BacklightHelper::setbrightness(const QVariantMap &args)
 {
     ActionReply reply;
 
-    int actual_brightness = args["brightnessvalue"].toInt();
+    int actual_brightness = args.value(QStringLiteral("brightness")).toInt();
 
     if (!m_isSupported) {
         reply = ActionReply::HelperErrorReply();
@@ -333,7 +267,7 @@ ActionReply BacklightHelper::setbrightnessvalue(const QVariantMap & args)
     return reply;
 }
 
-ActionReply BacklightHelper::syspath(const QVariantMap& args)
+ActionReply BacklightHelper::syspath(const QVariantMap &args)
 {
     Q_UNUSED(args);
 
@@ -349,7 +283,7 @@ ActionReply BacklightHelper::syspath(const QVariantMap& args)
     return reply;
 }
 
-ActionReply BacklightHelper::brightnessvaluemax(const QVariantMap & args)
+ActionReply BacklightHelper::brightnessmax(const QVariantMap &args)
 {
     Q_UNUSED(args);
 
@@ -386,8 +320,8 @@ ActionReply BacklightHelper::brightnessvaluemax(const QVariantMap & args)
         return reply;
     }
 
-    reply.addData("brightnessvaluemax", max_brightness);
-    //qCDebug(POWERDEVIL) << "data contains:" << reply.data()["brightnessvaluemax"];
+    reply.addData("brightnessmax", max_brightness);
+    //qCDebug(POWERDEVIL) << "data contains:" << reply.data()["brightnessmax"];
 
     return reply;
 }
