@@ -2,6 +2,7 @@
     Copyright (C) 2006 Kevin Ottens <ervin@kde.org>
     Copyright (C) 2008-2010 Dario Freddi <drf@kde.org>
     Copyright (C) 2010 Alejandro Fiestas <alex@eyeos.org>
+    Copyright (C) 2015 Kai Uwe Broulik <kde@privat.broulik.de>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -42,11 +43,13 @@
 class UdevHelper;
 class XRandRXCBHelper;
 class XRandrBrightness;
+class QPropertyAnimation;
 
 class Q_DECL_EXPORT PowerDevilUPowerBackend : public PowerDevil::BackendInterface
 {
     Q_OBJECT
     Q_DISABLE_COPY(PowerDevilUPowerBackend)
+
 public:
     explicit PowerDevilUPowerBackend(QObject* parent);
     virtual ~PowerDevilUPowerBackend();
@@ -54,11 +57,11 @@ public:
     virtual void init();
     static bool isAvailable();
 
-    virtual int brightnessValue(BrightnessControlType type = Screen) const;
-    virtual int brightnessValueMax(BrightnessControlType type = Screen) const;
+    virtual int brightness(BrightnessControlType type = Screen) const;
+    virtual int brightnessMax(BrightnessControlType type = Screen) const;
 
     virtual int brightnessKeyPressed(PowerDevil::BrightnessLogic::BrightnessKeyType type, BrightnessControlType controlType);
-    virtual bool setBrightnessValue(int brightnessValue, PowerDevil::BackendInterface::BrightnessControlType type = Screen);
+    virtual void setBrightness(int value, PowerDevil::BackendInterface::BrightnessControlType type = Screen);
     virtual KJob* suspend(PowerDevil::BackendInterface::SuspendMethod method);
 
 private:
@@ -82,8 +85,11 @@ private slots:
     void onDevicePropertiesChanged(const QString &ifaceName, const QVariantMap &changedProps, const QStringList &invalidatedProps);
 
 private:
+    void animationValueChanged(const QVariant &value);
+
     // upower devices
     QMap<QString, OrgFreedesktopUPowerDeviceInterface *> m_devices;
+    OrgFreedesktopUPowerDeviceInterface *m_displayDevice;
 
     // brightness
     QMap<BrightnessControlType, int> m_cachedBrightnessMap;
@@ -93,7 +99,9 @@ private:
     OrgFreedesktopUPowerInterface *m_upowerInterface;
     OrgFreedesktopUPowerKbdBacklightInterface *m_kbdBacklight;
     int m_kbdMaxBrightness;
-    int m_brightnessValueMax = 0;
+    int m_brightnessMax = 0;
+
+    QPropertyAnimation *m_brightnessAnimation = nullptr;
 
     // login1 interface
     QWeakPointer<QDBusInterface> m_login1Interface;
