@@ -20,7 +20,6 @@
 #include "powerdevilcore.h"
 
 #include "PowerDevilSettings.h"
-#include "screensaver_interface.h"
 
 #include "powerdevilaction.h"
 #include "powerdevilactionpool.h"
@@ -41,7 +40,7 @@
 #include <KNotification>
 #include <KServiceTypeTrader>
 
-// #include <KActivities/Consumer>
+#include <KActivities/Consumer>
 
 #include <QtCore/QTimer>
 #include <QtDBus/QDBusConnection>
@@ -58,7 +57,7 @@ Core::Core(QObject* parent)
     , m_backend(0)
     , m_notificationsWatcher(nullptr)
     , m_criticalBatteryTimer(new QTimer(this))
-//     , m_activityConsumer(new KActivities::Consumer(this))
+    , m_activityConsumer(new KActivities::Consumer(this))
     , m_pendingWakeupEvent(true)
 {
 }
@@ -85,9 +84,6 @@ void Core::loadCore(BackendInterface* backend)
     connect(m_backend, SIGNAL(backendReady()), this, SLOT(onBackendReady()));
     connect(m_backend, SIGNAL(backendError(QString)), this, SLOT(onBackendError(QString)));
     m_backend->init();
-
-    // Register DBus Metatypes
-    qDBusRegisterMetaType< StringStringMap >();
 }
 
 void Core::onBackendReady()
@@ -127,8 +123,9 @@ void Core::onBackendReady()
             this, SLOT(onKIdleTimeoutReached(int,int)));
     connect(KIdleTime::instance(), SIGNAL(resumingFromIdle()),
             this, SLOT(onResumingFromIdle()));
-//     connect(m_activityConsumer, SIGNAL(currentActivityChanged(QString)),
-//             this, SLOT(loadProfile()));
+    connect(m_activityConsumer, &KActivities::Consumer::currentActivityChanged, this, [this]() {
+        loadProfile();
+    });
 
     // Set up the policy agent
     PowerDevil::PolicyAgent::instance()->init();
@@ -138,7 +135,7 @@ void Core::onBackendReady()
 
     // Set up the critical battery timer
     m_criticalBatteryTimer->setSingleShot(true);
-    m_criticalBatteryTimer->setInterval(30000);
+    m_criticalBatteryTimer->setInterval(60000);
     connect(m_criticalBatteryTimer, SIGNAL(timeout()), this, SLOT(onCriticalBatteryTimerExpired()));
 
     // wait until the notification system is set up before firing notifications
@@ -194,26 +191,6 @@ QString Core::checkBatteryStatus(bool notify)
         }
     }
 
-    // Any recalled batteries?
-    foreach (const BackendInterface::RecallNotice &notice, m_backend->recallNotices()) {
-        // Notify, a battery has been recalled
-        if (m_loadedBatteriesUdi.size() == 1) {
-            lastMessage = i18n("Your battery might have been recalled by %1. Usually, when vendors recall the "
-                               "hardware, it is because of factory defects which are usually eligible for a "
-                               "free repair or substitution. Please check <a href=\"%2\">%1's website</a> to "
-                               "verify if your battery is faulted.", notice.vendor, notice.url);
-        } else {
-            lastMessage = i18n("One of your batteries (ID %3) might have been recalled by %1. "
-                               "Usually, when vendors recall the hardware, it is because of factory defects "
-                               "which are usually eligible for a free repair or substitution. "
-                               "Please check <a href=\"%2\">%1's website</a> to "
-                               "verify if your battery is faulted.", notice.vendor, notice.url, notice.batteryId);
-        }
-        if (notify) {
-            emitRichNotification("brokenbattery", i18n("Check Your Battery"), lastMessage);
-        }
-    }
-
     return lastMessage;
 }
 
@@ -236,6 +213,11 @@ void Core::reparseConfiguration()
     emit configurationReloaded();
 }
 
+QString Core::currentProfile() const
+{
+    return m_currentProfile;
+}
+
 void Core::loadProfile(bool force)
 {
     QString profileId;
@@ -249,10 +231,7 @@ void Core::loadProfile(bool force)
     KConfigGroup config;
 
     // Check the activity in which we are in
-    QString activity;/* = m_activityConsumer->currentActivity();*/
-    if (activity.isEmpty()) {
-        activity = "default";
-    }
+    QString activity = m_activityConsumer->currentActivity();
     qCDebug(POWERDEVIL) << "We are now into activity " << activity;
     KConfigGroup activitiesConfig(m_profilesConfig, "Activities");
     qCDebug(POWERDEVIL) << activitiesConfig.groupList() << activitiesConfig.keyList();
@@ -524,17 +503,17 @@ bool Core::emitBatteryChargePercentNotification(int currentPercent, int previous
         switch (PowerDevilSettings::batteryCriticalAction()) {
         case PowerDevil::BundledActions::SuspendSession::ShutdownMode:
             emitRichNotification("criticalbattery", i18n("Battery Critical (%1% Remaining)", currentPercent),
-                             i18n("Your battery level is critical, the computer will be halted in 30 seconds."));
+                             i18n("Your battery level is critical, the computer will be halted in 60 seconds."));
             m_criticalBatteryTimer->start();
             break;
         case PowerDevil::BundledActions::SuspendSession::ToDiskMode:
             emitRichNotification("criticalbattery", i18n("Battery Critical (%1% Remaining)", currentPercent),
-                             i18n("Your battery level is critical, the computer will be hibernated in 30 seconds."));
+                             i18n("Your battery level is critical, the computer will be hibernated in 60 seconds."));
             m_criticalBatteryTimer->start();
             break;
         case PowerDevil::BundledActions::SuspendSession::ToRamMode:
             emitRichNotification("criticalbattery", i18n("Battery Critical (%1% Remaining)", currentPercent),
-                             i18n("Your battery level is critical, the computer will be suspended in 30 seconds."));
+                             i18n("Your battery level is critical, the computer will be suspended in 60 seconds."));
             m_criticalBatteryTimer->start();
             break;
         default:
@@ -776,5 +755,3 @@ uint Core::backendCapabilities()
 }
 
 }
-
-#include "powerdevilcore.moc"
