@@ -46,14 +46,9 @@ K_PLUGIN_FACTORY(PowerDevilGeneralKCMFactory,
                  registerPlugin<GeneralPage>();
                 )
 
-typedef QMap< QString, QString > StringStringMap;
-Q_DECLARE_METATYPE(StringStringMap)
-
 GeneralPage::GeneralPage(QWidget *parent, const QVariantList &args)
         : KCModule(0, parent, args)
 {
-    qDBusRegisterMetaType< StringStringMap >();
-
     setButtons(Apply | Help);
 
 //     KAboutData *about =
@@ -119,8 +114,6 @@ void GeneralPage::fillUi()
 
     // modified fields...
 
-    connect(doNotInhibitLid, SIGNAL(stateChanged(int)), SLOT(changed()));
-
     connect(notificationsButton, SIGNAL(clicked()), SLOT(configureNotifications()));
 
     connect(lowSpin, SIGNAL(valueChanged(int)), SLOT(changed()));
@@ -143,8 +136,6 @@ void GeneralPage::fillUi()
 
 void GeneralPage::load()
 {
-    doNotInhibitLid->setChecked(PowerDevilSettings::doNotInhibitOnLidClose());
-
     lowSpin->setValue(PowerDevilSettings::batteryLowLevel());
     criticalSpin->setValue(PowerDevilSettings::batteryCriticalLevel());
 
@@ -158,8 +149,6 @@ void GeneralPage::configureNotifications()
 
 void GeneralPage::save()
 {
-    PowerDevilSettings::setDoNotInhibitOnLidClose(doNotInhibitLid->isChecked());
-
     PowerDevilSettings::setBatteryLowLevel(lowSpin->value());
     PowerDevilSettings::setBatteryCriticalLevel(criticalSpin->value());
 
